@@ -1,30 +1,20 @@
 package Image::Magick::PolyText::FreeType;
-{
-use base qw( Image::Magick::PolyText );
+
+use parent 'Image::Magick::PolyText';
 use strict;
 use warnings;
 
 use File::Temp;
+
 use Font::FreeType;
+
 use Image::Magick;
-use POSIX qw( ceil );
 
-our $VERSION = '1.0.3';
+use Moo;
 
-# ------------------------------------------------
-# Attributes.
+use POSIX 'ceil';
 
-my %debug        : ATTR(init_arg => 'debug',        default => 0);
-my %fill         : ATTR(init_arg => 'fill',         default => 'Red');
-my %image        : ATTR(init_arg => 'image');
-my %pointsize    : ATTR(init_arg => 'pointsize',    default => 16);
-my %rotate       : ATTR(init_arg => 'rotate',       default => 1);
-my %slide        : ATTR(init_arg => 'slide',        default => 0);
-my %stroke       : ATTR(init_arg => 'stroke',       default => 'Red');
-my %strokewidth  : ATTR(init_arg => 'strokewidth',  default => 1);
-my %text         : ATTR(init_arg => 'text');
-my %x            : ATTR(init_arg => 'x');
-my %y            : ATTR(init_arg => 'y');
+our $VERSION = '2.00';
 
 # ------------------------------------------------
 # Constants.
@@ -36,42 +26,35 @@ Readonly::Scalar my $pi => 3.14159265;
 
 sub annotate
 {
-	my $self = shift @_;
-	my $id   = ident $self;
-	my $font = $image{$id} -> Get('font');
+	my($self)	= @_;
+	my($font)	= $self -> image -> Get('font');
+	my($face)	= Font::FreeType -> new ->face($font, load_flags => FT_LOAD_NO_HINTING);
 
-	print "Font: $font. \n";
+	$face -> set_char_size($self -> pointsize, 0, 72, 72);
 
-	my $face = Font::FreeType -> new() ->face($font, load_flags => FT_LOAD_NO_HINTING);
-
-	$face -> set_char_size($pointsize{$id}, 0, 72, 72);
-
-	if ($debug{$id})
-	{
-		$self -> dump();
-	}
+	$self -> dump if ($self -> debug);
 
 	my $bitmap;
 	my $i;
 	my $result;
 	my $rotation;
-	my @text = split //, $text{$id};
+	my @text = split //, $self -> text;
 	my @value;
-	my $x = $x{$id}[0];
+	my $x = ${$self -> x}[0];
 	my $y;
 
-	if ($slide{$id})
+	if ($self -> slide)
 	{
-		my $b    = Math::Bezier -> new(map{($x{$id}[$_], $y{$id}[$_])} 0 .. $#{$x{$id} });
-		($x, $y) = $b -> point($slide{$id});
+		my $b    = Math::Bezier -> new(map{(${$self -> x}[$_], ${$self -> y}[$_])} 0 .. $#{$self -> x});
+		($x, $y) = $b -> point($self -> slide);
 	}
 
 	for ($i = 0; $i <= $#text; $i++)
 	{
-		@value    = Math::Interpolate::robust_interpolate($x, $x{$id}, $y{$id});
-		$rotation = $rotate{$id} ? 180 * $value[1] / $pi : 0; # Convert radians to degrees.
+		@value    = Math::Interpolate::robust_interpolate($x, $self -> x, $self -> y);
+		$rotation = $self -> rotate ? 180 * $value[1] / $pi : 0; # Convert radians to degrees.
 		$y        = $value[0];
-		$result   = $image{$id} -> Composite
+		$result   = $self -> image -> Composite
 		(
 		compose => 'Over',
 		image   => $self -> glyph2svg2bitmap($face, $text[$i], $rotation),
@@ -81,7 +64,7 @@ sub annotate
 
 		die $result if $result;
 
-		$x += $pointsize{$id};
+		$x += $self -> pointsize;
 	}
 
 }	# End of annotate.
@@ -90,22 +73,19 @@ sub annotate
 
 sub glyph2svg2bitmap
 {
-	my $self     = shift @_;
-	my $face     = shift @_;
-	my $char     = shift @_;
-	my $rotation = shift @_;
-	my $glyph    = $face -> glyph_from_char_code(ord $char);
+	my($self, $face, $char, $rotation)	= @_;
+	my($glyph)							= $face -> glyph_from_char_code(ord $char);
 
 	if (! (defined $glyph && $glyph -> has_outline() ) )
 	{
 		$glyph = $face -> glyph_from_char_code('?');
 	}
 
-	my ($xmin, $ymin, $xmax, $ymax) = $glyph -> outline_bbox();
+	my($xmin, $ymin, $xmax, $ymax) = $glyph -> outline_bbox;
 	$xmax    = ceil $xmax;
 	$ymax    = ceil $ymax;
-	my $path = $glyph -> svg_path();
-	my $fh   = File::Temp -> new();
+	my $path = $glyph -> svg_path;
+	my $fh   = File::Temp -> new;
 
 	print $fh
 	"<?xml version='1.0' encoding='UTF-8'?>\n" .
@@ -122,7 +102,7 @@ sub glyph2svg2bitmap
     "</svg>\n";
 	close $fh;
 
-	my $bitmap = Image::Magick -> new();
+	my $bitmap = Image::Magick -> new;
 	my $result  = $bitmap -> Read($fh -> filename() );
 
 	die $result if $result;
@@ -151,8 +131,6 @@ sub glyph2svg2bitmap
 
 # ------------------------------------------------
 
-}	# End of package.
-
 1;
 
 =head1 NAME
@@ -163,20 +141,20 @@ C<Image::Magick::PolyText::FreeType> - Draw text along a polyline using FreeType
 
 	my $polytext = Image::Magick::PolyText::FreeType -> new
 	({
-	debug        => 0,
-	fill         => 'Red',
-	image        => $image,
-	pointsize    => 16,
-	rotate       => 1,
-	slide        => 0.1,
-	stroke       => 'Red',
-	strokewidth  => 1,
-	text         => 'Draw.text.along.a.polyline', # Can't use spaces!
-	x            => [0, 1, 2, 3, 4],
-	'y'          => [0, 1, 2, 3, 4], # y eq tr so syntax highlighting stuffed without ''.
+		debug        => 0,
+		fill         => 'Red',
+		image        => $image,
+		pointsize    => 16,
+		rotate       => 1,
+		slide        => 0.1,
+		stroke       => 'Red',
+		strokewidth  => 1,
+		text         => 'Draw.text.along.a.polyline', # Can't use spaces!
+		x            => [0, 1, 2, 3, 4],
+		y            => [0, 1, 2, 3, 4],
 	});
 
-	$polytext -> annotate();
+	$polytext -> annotate;
 
 Warning: Experimental code - Do not use.
 
@@ -184,7 +162,7 @@ Warning: Experimental code - Do not use.
 
 C<Image::Magick::PolyText::FreeType> is a pure Perl module.
 
-It is a convenient wrapper around C<Image::Magick's Annotate()> method, for drawing text along a polyline.
+It is a convenient wrapper around the C<Image::Magick Annotate()> method, for drawing text along a polyline.
 
 Warning: Experimental code - Do not use.
 
@@ -204,7 +182,7 @@ Warning: Experimental code - Do not use.
 
 new(...) returns an C<Image::Magick::PolyText::FreeType> object.
 
-This is the class's contructor.
+This is the class contructor.
 
 Usage: Image::Magick::PolyText::FreeType -> new({...}).
 
@@ -214,7 +192,7 @@ For each parameter you wish to use, call new as new({param_1 => value_1, ...}).
 
 =over 4
 
-=item debug
+=item o debug
 
 Takes either 0 or 1 as its value.
 
@@ -224,17 +202,17 @@ When set to 1, the module writes to STDOUT, and plots various stuff on your imag
 
 This parameter is optional.
 
-=item fill
+=item o fill
 
 Takes an C<Image::Magick> color as its value.
 
 The default value is 'Red'.
 
-The value is passed to C<Image::Magick's Annotate()> method.
+The value is passed to the C<Image::Magick Annotate()> method.
 
 This parameter is optional.
 
-=item image
+=item o image
 
 Takes an C<Image::Magick> object as its value.
 
@@ -242,17 +220,17 @@ There is no default value.
 
 This parameter is mandatory.
 
-=item pointsize
+=item vpointsize
 
 Takes an integer as its value.
 
 The default value is 16.
 
-The value is passed to C<Image::Magick's Annotate()> method.
+The value is passed to the C<Image::Magick Annotate()> method.
 
 This parameter is optional.
 
-=item rotate
+=item vrotate
 
 Takes either 0 or 1 as its value.
 
@@ -265,7 +243,7 @@ at the 'current' (x, y) position.
 
 This parameter is optional.
 
-=item slide
+=item o slide
 
 Takes a real number in the range 0.0 to 1.0 as its value.
 
@@ -275,38 +253,38 @@ The value represents how far along the polyline (0.0 = 0%, 1.0 = 100%) to slide
 
 The parameter is optional.
 
-=item stroke
+=item o stroke
 
 Takes an C<Image::Magick> color as its value.
 
 The default value is 'Red'.
 
-The value is passed to C<Image::Magick's Annotate()> method.
+The value is passed to the C<Image::Magick Annotate()> method.
 
 This parameter is optional.
 
-=item strokewidth
+=item o strokewidth
 
 Takes an integer as its value.
 
 The default value is 1.
 
-The value is passed to C<Image::Magick's Annotate()> method.
+The value is passed to the C<Image::Magick Annotate()> method.
 
 This parameter is optional.
 
-=item text
+=item o text
 
 Takes a string of characters as its value.
 
 There is no default value.
 
 This text is split character by character, and each character is drawn with a separate call to
-C<Image::Magick's Annotate()> method. This is a very slow process. You have been warned.
+the C<Image::Magick Annotate()> method. This is a very slow process. You have been warned.
 
 This parameter is mandatory.
 
-=item x
+=item o x
 
 Takes an array ref of x (co-ordinate) values as its value.
 
@@ -316,7 +294,7 @@ These co-ordinates are the x-axis values of the polyline.
 
 This parameter is mandatory.
 
-=item y
+=item o y
 
 Takes an array ref of y (abcissa) values as its value.
 
@@ -328,28 +306,34 @@ This parameter is mandatory.
 
 =back
 
-=head1 Method: annotate()
+=head1
+
+=head2 annotate()
 
 This method writes the text on to your image.
 
-=head1 Method: draw({options})
+=head2 draw(%options)
+
+%options is an optional hash of (key => value) pairs.
 
 This method draws a line through the data points.
 
 The default line color is green.
 
-The options are a hash ref which is passed to C<Image::Magick's Draw()> method, so any option
+The options are a hash ref which is passed to the C<Image::Magick Draw()> method, so any option
 acceptable to C<Draw()> is acceptable here.
 
 A typical usage would be $polytext -> draw({stroke => 'blue'});
 
-=head1 Method: highlight_data_points({options})
+=head2 highlight_data_points(%options)
+
+%options is an optional hash of (key => value) pairs.
 
 This method draws little (5x5 pixel) rectangles centered on the data points.
 
 The default rectangle color is red.
 
-The options are a hash ref which is passed to C<Image::Magick's Draw()> method, so any option
+The options are a hash ref which is passed to the C<Image::Magick Draw()> method, so any option
 acceptable to C<Draw()> is acceptable here.
 
 A typical usage would be $polytext -> highlight_data_points({stroke => 'black'});
@@ -358,29 +342,23 @@ A typical usage would be $polytext -> highlight_data_points({stroke => 'black'})
 
 See the file examples/ptf.pl in the distro.
 
-=head1 Required Modules
+=head1 Machine-Readable Change Log
 
-=over 4
+The file Changes was converted into Changelog.ini by L<Module::Metadata::Changes>.
 
-=item Class::Std
+=head1 Version Numbers
 
-=item File::Temp
+Version numbers < 1.00 represent development versions. From 1.00 up, they are production versions.
 
-=item Font::FreeType
+=head1 Repository
 
-=item Math::Bezier
+L<https://github.com/ronsavage/Image-Magick-PolyText>
 
-=item Math::Interpolate
+=head1 Support
 
-=item POSIX
+Email the author, or log a bug on RT:
 
-=item Readonly
-
-=back
-
-=head1 Changes
-
-See the ChangeLog file.
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=Image-Magick-PolyText>.
 
 =head1 Author
 
@@ -390,11 +368,10 @@ Home page: http://savage.net.au/index.html
 
 =head1 Copyright
 
-Australian copyright (c) 2007, Ron Savage. All rights reserved.
-
+Australian copyright (c) 2007, Ron Savage.
 	All Programs of mine are 'OSI Certified Open Source Software';
 	you can redistribute them and/or modify them under the terms of
-	The Artistic License, a copy of which is available at:
-	http://www.opensource.org/licenses/index.html
+	The Perl License, a copy of which is available at:
+	http://dev.perl.org/licenses/
 
 =cut
